@@ -1,6 +1,7 @@
-Sys.setenv(R_TESTS="")
+Sys.unsetenv("R_TESTS")
 library(testthat)
 library(DDD)
+library(Rcpp)
 
 test_check("DDD")
 
